@@ -25,7 +25,7 @@ class SparkInitializer(object):
     Create a new initializer
     Param user The user login for the git repo
     """
-    def __init__(self):
+    def __init__(self, system):
         self.template_dir = None
         self.template_repo = None
 
