@@ -23,14 +23,16 @@ from subprocess import Popen, PIPE
 
 DOCKER_SOCK='unix:////var/run/ferry.sock'
 
-""" Docker instance """
 class DockerInstance(object):
+    """ Docker instance """
+
     def __init__(self, json_data=None):
         if not json_data:
             self.container = ''
             self.vm = 'local'
             self.service_type = None
             self.host_name = None
+            self.manage_ip = None
             self.external_ip = None
             self.internal_ip = None
             self.ports = {}
@@ -42,11 +44,13 @@ class DockerInstance(object):
             self.default_user = None
             self.name = None
             self.args = None
+            self.tunnel = False
         else:
             self.container = json_data['container']
             self.vm = json_data['vm']
             self.service_type = json_data['type']
             self.host_name = json_data['hostname']
+            self.manage_ip = json_data['manage_ip']
             self.external_ip = json_data['external_ip']
             self.internal_ip = json_data['internal_ip']
             self.ports = json_data['ports']
@@ -58,12 +62,14 @@ class DockerInstance(object):
             self.keyname =json_data['keyname']
             self.privatekey = json_data['privatekey']
             self.volumes = json_data['volumes']
+            self.tunnel = json_data['tunnel']
 
     """
     Return in JSON format. 
     """
     def json(self):
         json_reply = { '_type' : 'docker',
+                       'manage_ip' : self.manage_ip,
                        'external_ip' : self.external_ip,
                        'internal_ip' : self.internal_ip,
                        'ports' : self.ports,
@@ -78,7 +84,8 @@ class DockerInstance(object):
                        'volumes' : self.volumes,
                        'user' : self.default_user,
                        'name' : self.name,
-                       'args' : self.args }
+                       'args' : self.args,
+                       'tunnel' : self.tunnel }
         return json_reply
 
 
@@ -125,6 +132,9 @@ class DockerCLI(object):
             # The server is not supplied, so just execute
             # the command locally. 
             proc = Popen(cmd, stdout=PIPE, stderr=PIPE, shell=True)
+            if read_output:
+                out = proc.stdout.read()
+                err = proc.stderr.read()
         else:
             # Do not store results in hosts file or warn about 
             # changing ssh keys. Also use the key given to us by the fabric. 
@@ -146,7 +156,7 @@ class DockerCLI(object):
             # All the possible errors that might happen when
             # we try to connect via ssh. 
             if read_output:
-                out, err = robust_com(ssh)
+                out, err, success = robust_com(ssh)
             else:
                 # The user does not want us to read the output.
                 # That means we can't really check for errors :(
@@ -154,7 +164,7 @@ class DockerCLI(object):
 
         if read_output:
             # Read both the standard out and error. 
-            return proc.stdout.read(), proc.stderr.read()
+            return out, err
         else:
             # The user does not want to read the output.
             return proc
@@ -339,7 +349,7 @@ class DockerCLI(object):
                                  service_type = service_type, 
                                  args = args)
 
-    def run(self, service_type, image, volumes, keydir, keyname, privatekey, open_ports, host_map=None, expose_group=None, hostname=None, default_cmd=None, args=None, lxc_opts=None, server=None, user=None, inspector=None, background=False):
+    def run(self, service_type, image, volumes, keydir, keyname, privatekey, open_ports, host_map=None, expose_group=None, hostname=None, default_cmd=None, args=None, lxc_opts=None, server=None, user=None, inspector=None, background=False, simulate=False):
         """
         Start a brand new container
         """
@@ -398,6 +408,11 @@ class DockerCLI(object):
         cmd = self.docker + ' ' + self.run_cmd + ' ' + flags + ' ' + image + ' ' + default_cmd
         logging.warning(cmd)
 
+        # Check if this is a simulated run. If so,
+        # just return None. 
+        if simulate:
+            return None
+
         if background:
             proc = self._execute_cmd(cmd, server, user, False)
             container = None
