@@ -38,6 +38,10 @@ class CloudFabric(object):
         self.docker_user = self.cli.docker_user
         self.inspector = CloudInspector(self)
 
+        # The system returns information regarding 
+        # the instance types. 
+        self.system = self.launcher.system
+
     def _load_class(self, class_name):
         """
         Dynamically load a class
@@ -61,14 +65,15 @@ class CloudFabric(object):
         launcher = conf["system"]["mode"]
         self.launcher = self._load_class(launcher)
 
-        # The name of the data network device (eth*). 
-        self.data_network = conf["system"]["network"]
-
         # Determine if we are using this fabric in proxy
         # mode. Proxy mode means that the client is external
         # to the network, but controller has direct access. 
         self.proxy = bool(conf["system"]["proxy"])
 
+        # Check if the launcher supports proxy mode. 
+        if self.proxy and not self.launcher.support_proxy():
+            logging.error("%s does not support proxy mode" % self.launcher.name)
+
     def get_data_dir(self):
         return "/ferry/data"
 
@@ -101,9 +106,9 @@ class CloudFabric(object):
         
         # Then need to restart Ferry on all the hosts. 
         logging.warning("restarting ferry...")
-        cmd = "source /etc/profile && ferry server"
+        cmd = "source /etc/profile && ferry server -n"
         for ip in addrs:
-            output, err = self.cmd_raw(self.cli.key, ip, cmd, self.docker_user)
+            output, err, _ = self.cmd_raw(self.cli.key, ip, cmd, self.docker_user)
 
         # Finally, restart the stopped containers. 
         logging.warning("restarting containers...")
@@ -111,7 +116,7 @@ class CloudFabric(object):
         for c in containers:
             # Before restarting the containers, we need to learn their
             # container IDs. It should be stored on a cidfile. 
-            output, err = self.cmd_raw(self.cli.key, c.external_ip, cmd, self.launcher.ssh_user)
+            output, err, _ = self.cmd_raw(self.cli.key, c.external_ip, cmd, self.launcher.ssh_user)
             c.container = output.strip()
             self.cli.start(image = c.image,
                            container = c.container, 
@@ -144,43 +149,50 @@ class CloudFabric(object):
         """
         Verify that the public key has been copied over correctly. 
         """
-        out, _ = self.cmd_raw(key = self.cli.key, 
-                              ip = server, 
-                              cmd = "ls /ferry/keys",
-                              user = self.launcher.ssh_user)
-        if out.strip() == "":
+        out, _, _ = self.cmd_raw(key = self.cli.key, 
+                                 ip = server, 
+                                 cmd = "ls /ferry/keys",
+                                 user = self.launcher.ssh_user)
+        if out and out.strip() == "":
             return False
-        else:
+        elif out:
             logging.warning("found ssh key: " + out.strip())
             return True
+        else:
+            return False
 
     def _verify_ferry_server(self, server):
         """
         Verify that the docker daemon is actually running on the server. 
         """
+
+        # Try a couple times before giving up. 
         for i in range(0, 2):
-            out, _ = self.cmd_raw(key = self.cli.key, 
-                                  ip = server, 
-                                  cmd = "if [ -f /var/run/ferry.pid ]; then echo \"launched\"; fi",
-                                  user = self.launcher.ssh_user)
-            if out.strip() != "":
+            out, err, success = self.cmd_raw(key = self.cli.key, 
+                                             ip = server, 
+                                             cmd = "if [ -f /var/run/ferry.pid ]; then echo \"launched\"; fi",
+                                             user = self.launcher.ssh_user)
+            if success and out and out.strip() != "":
                 logging.warning("docker daemon " + out.strip())
                 return True
-            time.sleep(2)
+            elif not success:
+                return False
+            else:
+                time.sleep(6)
         return False
 
     def _execute_server_init(self, server):
         """
         Restart the Ferry docker daemon. 
         """
-        out, err = self.cmd_raw(key = self.cli.key, 
-                                ip = server, 
-                                cmd = "ferry server -n && sleep 3",
-                                user = self.launcher.ssh_user)
+        out, err, _ = self.cmd_raw(key = self.cli.key, 
+                                   ip = server, 
+                                   cmd = "ferry server -n && sleep 3",
+                                   user = self.launcher.ssh_user)
         logging.warning("restart ferry out: " + out)
         logging.warning("restart ferry err: " + err)
         
-    def execute_docker_containers(self, cinfo, lxc_opts, private_ip, public_ip):
+    def execute_docker_containers(self, cinfo, lxc_opts, private_ip, server_ip, background=True, simulate=False):
         """
         Run the Docker container and use the cloud inspector to get information
         about the container/VM.
@@ -188,7 +200,7 @@ class CloudFabric(object):
 
         host_map = None
         host_map_keys = []
-        mounts = {}
+        mounts = {}        
 
         if not 'default_cmd' in cinfo:
             cinfo['default_cmd'] = "/service/sbin/startnode init"
@@ -205,20 +217,22 @@ class CloudFabric(object):
                                  default_cmd = cinfo['default_cmd'],
                                  args= cinfo['args'],
                                  lxc_opts = lxc_opts,
-                                 server = public_ip,
+                                 server = server_ip,
                                  user = self.launcher.ssh_user, 
                                  inspector = self.inspector,
-                                 background = True)
+                                 background = background,
+                                 simulate= simulate)
         if container:
+            container.manage_ip = server_ip
             container.internal_ip = private_ip
             if self.proxy:
+                # Otherwise, the controller can only interact with the
+                # VMs via their public IP address. 
+                container.external_ip = server_ip
+            else:
                 # When the fabric controller is acting in proxy mode, 
                 # it can contact the VMs via their private addresses. 
                 container.external_ip = private_ip
-            else:
-                # Otherwise, the controller can only interact with the
-                # VMs via their public IP address. 
-                container.external_ip = public_ip
 
             container.vm = self.launcher.default_personality
             container.default_user = self.cli.docker_user
@@ -240,9 +254,19 @@ class CloudFabric(object):
 
     def alloc(self, cluster_uuid, service_uuid, container_info, ctype):
         """
-        Allocate a new cluster. 
+        Allocate a new service cluster. 
         """
-        return self.launcher.alloc(cluster_uuid, service_uuid, container_info, ctype, self.proxy)
+        containers = self.launcher.alloc(cluster_uuid, service_uuid, container_info, ctype, self.proxy)
+        
+        if not containers:
+            # The underlying cloud infrastructure could not allocate
+            # the service cluster. Sometimes it's just a temporary glitch, so
+            # get rid of the attempt and try some more. 
+            logging.error("Failed to allocate service cluster. Trying again.")
+            self.launcher._delete_stack(cluster_uuid, service_uuid)
+            return self.launcher.alloc(cluster_uuid, service_uuid, container_info, ctype, self.proxy)
+        else:
+            return containers
 
     def stop(self, cluster_uuid, service_uuid, containers):
         """
@@ -262,7 +286,7 @@ class CloudFabric(object):
         ferry = 'ferry quit'
         for c in containers:
             self.cmd_raw(c.privatekey, c.external_ip, halt, c.default_user)
-            self.cmd_raw(self.cli.key, c.external_ip, ferry, c.default_user)
+            self.cmd_raw(self.cli.key, c.manage_ip, ferry, self.launcher.ssh_user)
 
         # Now go ahead and stop the VMs. 
         self.launcher._stop_stack(cluster_uuid, service_uuid)
@@ -292,14 +316,14 @@ class CloudFabric(object):
         """
         all_output = {}
         for c in containers:
-            output, _ = self.cmd_raw(c.privatekey, c.external_ip, cmd, c.default_user)
+            output, _, _ = self.cmd_raw(c.privatekey, c.external_ip, cmd, c.default_user)
             if output.strip() != "":
                 all_output[c.host_name] = output.strip()
         return all_output
 
     def cmd_raw(self, key, ip, cmd, user):
         ip = user + '@' + ip
-        ssh = 'ssh -o ConnectTimeout=20 -o StrictHostKeyChecking=no -o UserKnownHostsFile=/dev/null -i ' + key + ' -t -t ' + ip + ' \'%s\'' % cmd
+        ssh = 'LC_ALL=C && ssh -o ConnectTimeout=20 -o StrictHostKeyChecking=no -o UserKnownHostsFile=/dev/null -i ' + key + ' -t -t ' + ip + ' \'%s\'' % cmd
         logging.warning(ssh)
         return robust_com(ssh)
 
