@@ -17,6 +17,7 @@ from ferry.docker.docker import DockerCLI
 from ferry.docker.docker import DockerInspector
 from ferry.fabric.com import robust_com
 from ferry.ip.client import DHCPClient
+from ferry.config.system.info import System
 import ferry.install
 import json
 import logging
@@ -34,6 +35,10 @@ class LocalFabric(object):
         self.inspector = DockerInspector(self.cli)
         self.bootstrap = bootstrap
 
+        # The system returns information regarding 
+        # the instance types. 
+        self.system = System()
+
         # Bootstrap mode means that the DHCP network
         # isn't available yet, so we can't use the network. 
         if not bootstrap:
@@ -288,9 +293,9 @@ class LocalFabric(object):
     def cmd_raw(self, key, ip, cmd, user):
         if key:
             ip = user + '@' + ip
-            ssh = 'ssh -o ConnectTimeout=20 -o StrictHostKeyChecking=no -o UserKnownHostsFile=/dev/null -i ' + key + ' -t -t ' + ip + ' \'%s\'' % cmd
+            ssh = 'LC_ALL=C && ssh -o ConnectTimeout=20 -o StrictHostKeyChecking=no -o UserKnownHostsFile=/dev/null -i ' + key + ' -t -t ' + ip + ' \'%s\'' % cmd
             logging.warning(ssh)
-            out, _ = robust_com(ssh)
+            out, _, _ = robust_com(ssh)
             return out
         else:
             return ''
